module ComplexHelper
  def sanitize_title(title)
    return if title.nil?

    # remove extra spaces from beginning and end
    title = title.strip

    # Remove any characters other than a-z, 0-9, ., and -
    title.gsub!(/[^a-zA-Z0-9.\-\s]/, '')

    # Replace consecutive spaces with a single space
    title.gsub!(/\s+/, ' ')

    # Replace consecutive dots with a single dot
    title.gsub!(/\.{2,}/, '.')

    # Replace consecutive hyphens with a single hyphen
    title.gsub!(/-{2,}/, '-')

    # Bucket titles must begin and end with a letter or number
    title.sub!(/\A[^a-zA-Z0-9]*/, '')
    title.sub!(/[^a-zA-Z0-9]*\z/, '')

    title = title.downcase

    # Check for xn-- prefix and sthree- prefix
    title.gsub!(/\Asthree-/i, '')

    # Check for -s3alias suffix and --ol-s3 suffix
    title.sub!(/-s3alias\z/i, '')
    title
  end
  
  def filter_metadata_json_file(object)
    metadata = object.to_json
    parsed_data = JSON.parse(metadata)

    case object.class.name
    when 'ComplexSubject'
      filtered_data = parsed_data.slice('id', 'subject_title', 'subject_species', 'subject_type', 'subject_sex', 'subject_age')
    when 'ComplexSession'
      filtered_data = parsed_data.slice('id', 'session_title', 'session_date_recorded')
    when 'ComplexModality'
      filtered_data = parsed_data.slice('id', 'modality_title', 'modality')
    else
      filtered_data = parsed_data.slice('id', 'depositor', 'date_created', 'date_modified',
                                        'title', 'description', 'resource_type', 'keyword', 'license',
                                        'alternative_title', 'subject', 'language', 'based_near', 'software_version',
                                        'publisher', 'doi', 'files_size', 'format',
                                        'experiment_description', 'crc_resource_type', 'coverage', 'approval_number',
                                        'extra_information')
      filtered_data['Creators and Contributors'] = parsed_data['complex_person'].map { |person| person.slice('first_name', 'last_name', 'name', 'email', 'role', 'orcid', 'affiliation')} if parsed_data['complex_person'].present?
      filtered_data['Related items'] = parsed_data['complex_relation'].map { |relation| relation.slice('title', 'url', 'relationship')} if parsed_data['complex_relation'].present?
      filtered_data['Date'] = parsed_data['complex_date'].map { |date| date.slice('date', 'description')} if parsed_data['complex_date'].present?
      filtered_data['Funding reference'] = parsed_data['complex_funding_reference'].map { |funding| funding.slice('funder_identifier', 'funder_name', 'award_number', 'award_uri', 'award_title')} if parsed_data['complex_funding_reference'].present?
      filtered_data['Identifiers'] = parsed_data['complex_identifier'].map { |identifier| identifier.slice('identifier', 'scheme')} if parsed_data['complex_identifier'].present?
      filtered_data
    end

    filtered_data.to_json
  end
end